@@ -12,7 +12,8 @@ from ._types import(fixpoint,
                     is_complex,
                     to_1d,
                     to_2d, 
-                    to_callback)
+                    to_callback,
+                    as1darray)
 
 from ._probe import probe, probe_filter
 
@@ -26,7 +27,9 @@ from ._math import(cexp,
                    gamma, 
                    join_subsets, 
                    cross_subsets,
-                   corcof)
+                   corcof,
+                   standartize,
+                   normalize)
 
 from ._geometry import (calc_line,
                         flip_vector,
