@@ -1,10 +1,10 @@
 import numpy as np
 from .. import operators
 
-__all__=['movingaverage','movav']
+__all__=['moving_average','movav']
 
 #------------------------------------------
-def movingaverage(vector,av_cof, mode='same'):
+def moving_average(vector,av_cof, mode='same'):
     '''
     Simple Moving Average or Weighted  Moving Average
     
